# I/O

::: geoarrow.rust.core
    options:
      filters:
        - "!^_"
      members:
        - from_ewkb
        - from_wkb
        - from_wkt
        - to_wkb
        - read_csv
        - read_flatgeobuf
        - read_geojson
        - read_geojson_lines
        - read_parquet
        - write_csv
        - write_flatgeobuf
        - write_geojson
